<?php
$TRANSLATIONS = array(
"Pictures" => "Imágenes",
"Picture view" => "Vista de imágen",
"Error loading slideshow template" => "Error cargando plantilla de presentación.",
"Share" => "Compartir",
"File list" => "Lista de archivos"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
